'use strict';

const axios = require('axios');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e["default"] : e; }

const axios__default = /*#__PURE__*/_interopDefaultLegacy(axios);

function responseMap(response, longUrl, provider) {
  const responseType = response.headers["content-type"].split(";")[0];
  if (!["text/plain", "text/html"].includes(responseType)) {
    if (response.data?.url) {
      return { longUrl, shortUrl: response.data.url };
    } else if (response.data?.shortUrl) {
      return { longUrl, shortUrl: response.data.shortUrl };
    } else if (response.data?.shortenedUrl) {
      return { longUrl, shortUrl: response.data.shortenedUrl };
    } else if (response.data?.short) {
      return { longUrl, shortUrl: response.data.short };
    } else if (response.data?.short_url) {
      return { longUrl, shortUrl: response.data.short_url };
    } else if (response.data?.result_url) {
      return { longUrl, shortUrl: response.data.result_url };
    }
  }
  if (["haha", "pwm", "cya"].includes(provider)) {
    return { longUrl, shortUrl: `https://${provider}.se/${response.data}` };
  }
  return { longUrl, shortUrl: response.data };
}
const getAxios = (provider, longUrl, option) => {
  if (provider.method === "get") {
    return axios__default.get(provider.url + longUrl, { timeout: option.timeout });
  } else {
    return axios__default.post(provider.url, provider.body(longUrl), {
      timeout: option.timeout
    });
  }
};
const ValidProviders = {
  isgd: {
    url: "https://is.gd/create.php?format=simple&url=",
    method: "get"
  },
  cdpt: {
    url: "https://cdpt.in/shorten?url=",
    method: "get"
  },
  vgd: {
    url: "https://v.gd/create.php?format=simple&url=",
    method: "get"
  },
  haha: {
    url: "https://www.haha.se/lank.php?dataLank=",
    method: "get"
  },
  cya: {
    url: "https://www.haha.se/lank.php?dataLank=",
    method: "get"
  },
  pwm: {
    url: "https://www.haha.se/lank.php?dataLank=",
    method: "get"
  },
  "4hnet": {
    url: "https://4h.net/api/?url=",
    method: "get"
  },
  vurl: {
    url: "https://vurl.com/api.php?url=",
    method: "get"
  },
  tinube: {
    url: "https://api.tinu.be/api/shorten",
    method: "post",
    body: (val) => {
      return { longUrl: val };
    }
  },
  hideuri: {
    url: "https://hideuri.com/api/v1/shorten",
    method: "post",
    body: (val) => {
      return { url: val };
    }
  },
  rbgy: {
    url: "https://free-url-shortener.rb.gy/shorten",
    method: "post",
    body: (val) => {
      return { destination: val, "dryRun": true };
    }
  }
};
const index = async (longUrl, option = { provider: "isgd", timeout: 2e3 }) => {
  try {
    const response = await getAxios(
      ValidProviders[option.provider],
      longUrl,
      option
    );
    return responseMap(response, longUrl, option.provider);
  } catch (error) {
    throw error;
  }
};

module.exports = index;
